==> okteta-0.25.3.tar.xz: okteta-0.25.3/kasten/controllers/view/stringsextract/stringsextracttoolview.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "stringsextracttoolview.h"

// tool
#include "stringsextractview.h"
#include "stringsextracttool.h"

namespace Kasten {

StringsExtractToolView::StringsExtractToolView(StringsExtractTool* tool)
    : mWidget(new StringsExtractView(tool))
{
}

StringsExtractToolView::~StringsExtractToolView()
{
    delete mWidget;
}

QWidget* StringsExtractToolView::widget()    const { return mWidget; }
QString StringsExtractToolView::title()      const { return mWidget->tool()->title(); }
AbstractTool* StringsExtractToolView::tool() const { return mWidget->tool(); }

}

==> okteta-0.26.2.tar.xz: okteta-0.26.2/kasten/controllers/view/stringsextract/stringsextracttoolview.cpp <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "stringsextracttoolview.hpp"

// tool
#include "stringsextractview.hpp"
#include "stringsextracttool.hpp"

namespace Kasten {

StringsExtractToolView::StringsExtractToolView(StringsExtractTool* tool)
    : mWidget(new StringsExtractView(tool))
{
}

StringsExtractToolView::~StringsExtractToolView()
{
    delete mWidget;
}

QWidget* StringsExtractToolView::widget()    const { return mWidget; }
QString StringsExtractToolView::title()      const { return mWidget->tool()->title(); }
AbstractTool* StringsExtractToolView::tool() const { return mWidget->tool(); }

}
